Name:           upower
Version:        1.90.2
Release:        1
Summary:        Power Management Service
License:        GPLv2+
URL:            http://upower.freedesktop.org/
Source0:        https://gitlab.freedesktop.org/upower/%{name}/-/archive/v%{version}/%{name}-v%{version}.tar.bz2

BuildRequires:  libtool intltool gettext libgudev1-devel gobject-introspection-devel gtk-doc systemd libxslt
BuildRequires:  libusbx-devel libimobiledevice-devel glib2-devel >= 2.34.0 libplist-devel 
BuildRequires:  meson
Requires:       gobject-introspection udev
%{?systemd_requires}

%description
UPower is an abstraction for enumerating power devices, listening to
device events and querying history and statistics. Any application or
service on the system can access the org.freedesktop.UPower service
via the system message bus. Some operations (such as suspending the
system) are restricted using PolicyKit.

%package devel
Summary: Headers and libraries for UPower
Requires: %{name} = %{version}-%{release}

%description devel
Headers and libraries for %{name}.

%package devel-docs
Summary: Developer documentation for for libupower-glib
Requires: %{name} = %{version}-%{release}
BuildArch: noarch

%description devel-docs
Developer documentation for for libupower-glib.

%prep
%autosetup -n %{name}-v%{version} -p1

%build
%meson \
  -Dman=true \
  -Dgtk-doc=true \
  -Dintrospection=enabled \

%meson_build

%install
%meson_install

%find_lang upower

%ldconfig_scriptlets

%post
%systemd_post upower.service

%preun
%systemd_preun upower.service

%postun
%systemd_postun_with_restart upower.service

%files -f upower.lang
%{!?_licensedir:%global license %%doc}
%license COPYING
%doc NEWS AUTHORS HACKING README
%{_libdir}/libupower-glib.so.*
%{_datadir}/dbus-1/system.d/*.conf
%{_udevrulesdir}/*.rules
%{_udevhwdbdir}/*hwdb
%dir %{_localstatedir}/lib/upower
%dir %{_sysconfdir}/UPower
%config %{_sysconfdir}/UPower/UPower.conf
%{_bindir}/*
%{_libexecdir}/*
%{_libdir}/girepository-1.0/*.typelib
%{_mandir}/man*
%{_datadir}/dbus-1/system-services/*.service
%{_unitdir}/*.service
%{_datadir}/installed-tests/upower/upower-integration.test

%files devel
%{_datadir}/dbus-1/interfaces/*.xml
%{_libdir}/libupower-glib.so
%{_libdir}/pkgconfig/*.pc
%{_datadir}/gir-1.0/*.gir
%dir %{_includedir}/libupower-glib
%{_includedir}/libupower-glib/up-*.h
%{_includedir}/libupower-glib/upower.h

%files devel-docs
%dir %{_datadir}/gtk-doc
%dir %{_datadir}/gtk-doc/html/UPower
%{_datadir}/gtk-doc/html/UPower/*

%changelog
* Thu Jan 25 2024 liuchao <liuchao173@huawei.com> - 1.90.2-1
- Update to 1.90.2:
  - Fix wireless devices not disappearing from Settings when disconnected
  - Require a newer libgudev to avoid bugs related to newline stripping when reading sysfs attributes
  - Add installed-tests files for use with gnome-desktop-testing
  - Fix integration test to work with system installed upower binary and under jhbuild
  - Detect headsets with kernel batteries such as Logitech and Steelseries headsets, and make them automatically disappear if the headset is turned off (if the kernel driver supports the wireless_status attribute)
  - Hide duplicate Logitech Bluetooth devices (Bolt-compatible devices connected through Bluetooth would show as 2 batteries)
  - Hide duplicate Logitech wireless devices when they get connected through USB as well
  - Fix Bluetooth device names not synchronising, and use user-chosen names when available
  - Handle the "present" sysfs attribute changing
  - Fix iDevices not appearing
  - Fix reading capacity_level with newer libgudev
  - Fix OpenBSD backend
  - Refactor internal battery handling into separate classes
  - Guess charging/discharging state based on energy rate (#196)
  - Fix polling after resume (#198)
  - Fix battery state guessing (#146)
  - Reload history when battery ID changes
  - Test fixes
  - Move state guessing into DisplayDevice
  - Always use 90% threshold to consider a battery full
  - Various test improvements
  - Fix mice showing up as keyboards (#189)
  - Allow unit test inspector to fail (#187)
  - Fix test cases when daemon shuts down too slowly (#188)
  - Remove broken wakeup DBus API
  - Tag UPS hid devices using hwdb and update list from upstream
  - Only permit Refresh method when in debug mode
  - Refactor device polling
  - Refactor udev device discovery and sibling detection
  - Improved testing and CI
  - Handle SIGTERM to trigger a clean shutdown
  - Improve polling of batteries after line-power "online" status change
  - Multiple wacom tablet detection fixes
  - Fix updates after a BT hid power supply moves in sysfs
  - Fix enumeration of "Whats Up!" devices on startup
  - Accept USB power supplies without warning
  - Allow building without gtk-doc

* Mon Mar 28 2022 lin zhang <lin.zhang@turbolinux.com.cn> - 0.99.17-1
- Update to 0.99.17

* Wed Nov 20 2019 mengxian <mengxian@huawei.com> - 0.99.8-5
- Fix compilation problem in x86_64

* Fri Aug 16 2019 openEuler Buildteam <buildteam@openeuler.org> - 0.99.8-4
- Package init
